@@ -21,8 +21,9 @@ import riscv_config.checker as riscv_config
 @click.option ('--debugspec','-dspec', type=click.Path(exists=True, resolve_path=True, readable=True), help = "Debug CSR File" )
 @click.option ('--customattr','-cattr', type=click.Path(exists=True, resolve_path=True, readable=True), help = "CUSTOM CSR Attributes File" )
 @click.option ('--workdir', default='./csrbox_work', type=click.Path(resolve_path=True, writable=True), help='Work directory path')
-@click.option ('--probeinst','-pinst',default='soc', type=str)
-def cli(verbose, isaspec, grpspec, customspec, debugspec, customattr, workdir, probeinst):
+@click.option ('--probeinst','-pinst',default='soc', type=str, help='Instance name of the module to be used for probe')
+@click.option ('--checked','-chk',default=False, is_flag=True, help='Assumes the *spec arguments are already checked and avoids calling riscv_config for validation')
+def cli(verbose, isaspec, grpspec, customspec, debugspec, customattr, workdir, probeinst, checked):
     utils.setup_logging(verbose)
     logger = logging.getLogger()
     logger.handlers = []
@@ -39,32 +40,36 @@ def cli(verbose, isaspec, grpspec, customspec, debugspec, customattr, workdir, p
         logger.debug('Removing old work directory and creating new one: ' + workdir)
         shutil.rmtree(workdir)
         os.mkdir(workdir)
+    if not checked:
 
-    try:
-        isa_file = riscv_config.check_isa_specs(isaspec, workdir, True)
-    except ValidationError as msg:
-        logger.error(msg)
-        return 1
-
-    if debugspec:
         try:
-            debug_file = riscv_config.check_debug_specs(debugspec, isa_file, workdir, True)
+            isa_file = riscv_config.check_isa_specs(isaspec, workdir, True)
         except ValidationError as msg:
             logger.error(msg)
             return 1
+
+        if debugspec:
+            try:
+                debug_file = riscv_config.check_debug_specs(debugspec, isa_file, workdir, True)
+            except ValidationError as msg:
+                logger.error(msg)
+                return 1
+        else:
+            debug_file = None
+
+
+        if customspec:
+            try:
+                custom_file = riscv_config.check_custom_specs(customspec, workdir, True)
+            except ValidationError as msg:
+                logger.error(msg)
+                return 1
+        else:
+            custom_file = None
     else:
-        debug_file = None
-
-
-    if customspec:
-        try:
-            custom_file = riscv_config.check_custom_specs(customspec, workdir, True)
-        except ValidationError as msg:
-            logger.error(msg)
-            return 1
-    else:
-        custom_file = None
-
+        isa_file = isaspec
+        custom_file = customspec
+        debug_file = debugspec
     bsv_dir  = os.path.join(workdir, "bsv/")
     if not os.path.exists(bsv_dir):   
         logger.debug('Creating new bsv directory: ' + bsv_dir) 
